use crate::m20240814_013106_create_user::User;
use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(DerankListMeta::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(DerankListMeta::Id)
                            .string()
                            .not_null()
                            .unique_key()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(DerankListMeta::Name).string())
                    .col(ColumnDef::new(DerankListMeta::Owner).string().not_null())
                    .col(
                        ColumnDef::new(DerankListMeta::Description)
                            .string()
                            .not_null(),
                    )
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-deranklistmeta-owner")
                            .from(DerankListMeta::Table, DerankListMeta::Owner)
                            .to(User::Table, User::Id)
                            .on_delete(ForeignKeyAction::SetNull),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(DerankListMeta::Table).to_owned())
            .await
    }
}

#[derive(DeriveIden)]
pub enum DerankListMeta {
    Table,
    Id,
    Name,
    Owner,
    Description,
}
