use crate::m20250317_192753_create_deranklist_meta::DerankListMeta;
use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(DerankListEntry::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(DerankListEntry::EntryId)
                            .string()
                            .not_null()
                            .unique_key()
                            .primary_key(),
                    )
                    .col(
                        ColumnDef::new(DerankListEntry::DerankListId)
                            .string()
                            .not_null(),
                    )
                    .col(
                        ColumnDef::new(DerankListEntry::UrlMatch)
                            .string()
                            .not_null(),
                    )
                    .col(ColumnDef::new(DerankListEntry::And).string())
                    .col(ColumnDef::new(DerankListEntry::Unless).string())
                    .col(
                        ColumnDef::new(DerankListEntry::Multiplier)
                            .double()
                            .not_null(),
                    )
                    .col(ColumnDef::new(DerankListEntry::Comment).string())
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-deranklistentry-deranklist")
                            .from(DerankListEntry::Table, DerankListEntry::DerankListId)
                            .to(DerankListMeta::Table, DerankListMeta::Id)
                            .on_delete(ForeignKeyAction::Cascade),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(DerankListEntry::Table).to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum DerankListEntry {
    Table,
    EntryId,
    DerankListId,
    UrlMatch,
    And,
    Unless,
    Multiplier,
    Comment,
}
