use crate::m20240814_013106_create_user::User;
use crate::m20250317_192753_create_deranklist_meta::DerankListMeta;
use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(DerankListSubscription::Table)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(DerankListSubscription::Id)
                            .string()
                            .not_null()
                            .unique_key()
                            .primary_key(),
                    )
                    .col(
                        ColumnDef::new(DerankListSubscription::UserId)
                            .string()
                            .not_null(),
                    )
                    .col(
                        ColumnDef::new(DerankListSubscription::DerankListId)
                            .string()
                            .not_null(),
                    )
                    .col(
                        ColumnDef::new(DerankListSubscription::Active)
                            .boolean()
                            .not_null(),
                    )
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-deranklistsubscription-userid")
                            .from(
                                DerankListSubscription::Table,
                                DerankListSubscription::UserId,
                            )
                            .to(User::Table, User::Id)
                            .on_delete(ForeignKeyAction::Cascade),
                    )
                    .foreign_key(
                        ForeignKey::create()
                            .name("fk-deranklistsubscription-deranklistid")
                            .from(
                                DerankListSubscription::Table,
                                DerankListSubscription::DerankListId,
                            )
                            .to(DerankListMeta::Table, DerankListMeta::Id)
                            .on_delete(ForeignKeyAction::Cascade),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(DerankListSubscription::Table).to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum DerankListSubscription {
    Table,
    Id,
    UserId,
    DerankListId,
    Active,
}
